<?php


require("../require.php");
$session=new Mysession("CONTINUE",false,false); 
if($_GET['flag']=="logout") {
	$session->stop();
}
//continueによってページを切り替える
//会員登録するページだったらTOPページへ飛ぶ

$continue = $_GET['continue'];
$pat = '/entry/';

if(preg_match($pat,$continue)){
	$flag = false;
}



if(isset($continue) && $flag){

	header("Location:http://localhost". $continue);
	exit;
}  else  {
	header("Location: index.php");
	exit;
}
